Index: trunk/MagicSoft/Mars/Changelog
===================================================================
--- trunk/MagicSoft/Mars/Changelog	(revision 3662)
+++ trunk/MagicSoft/Mars/Changelog	(revision 3663)
@@ -18,4 +18,11 @@
 
                                                  -*-*- END OF LINE -*-*-
+
+ 2004/04/06: Markus Gaug
+ 
+   * mcalib/MCalibrationChargePix.[h,cc]
+     - change names of the GetLoGain*() functions to 
+       GetConvertedLoGain*() for better clarity
+
 
  2004/04/05: Markus Gaug
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.h	(revision 3662)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.h	(revision 3663)
@@ -101,8 +101,8 @@
   Float_t GetConversionPINDiodeMethodErr()     const;
   Float_t GetConversionCombinedMethodErr()     const;
-  Float_t GetLoGainMean                 ()     const;
-  Float_t GetLoGainMeanErr              ()     const;
-  Float_t GetLoGainSigma                ()     const;
-  Float_t GetLoGainSigmaErr             ()     const;
+  Float_t GetConvertedLoGainMean        ()     const;
+  Float_t GetConvertedLoGainMeanErr     ()     const;
+  Float_t GetConvertedLoGainSigma       ()     const;
+  Float_t GetConvertedLoGainSigmaErr    ()     const;
   Float_t GetMeanConversionBlindPixelMethod()  const { return fMeanConversionBlindPixelMethod  ; }
   Float_t GetMeanConversionCombinedMethod()    const { return fMeanConversionCombinedMethod ;    }

Index: trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.cc	(revision 3662)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationChargePix.cc	(revision 3663)
@@ -65,4 +65,8 @@
 //  all error variables contain Variances in order to save the CPU-intensive square rooting 
 // 
+//  Low-Gain variables are stored internally unconverted, i.e. directly from the summed 
+//  FADC slices extraction results, but can be retrieved converted to High-Gain amplifications 
+//  by calls to: GetConvertedLoGainMean() or GetConvertedLoGainSigma()
+// 
 // See also: MCalibrationChargeCam, MCalibrationChargeCalc,
 //           MHCalibrationChargeCam, MHCalibrationChargePix
@@ -325,8 +329,8 @@
 // --------------------------------------------------------------------------
 //
 // Get the Low Gain Mean: 
 // Returns fLoGainMean multiplied with fConversionHiLo
 //
-Float_t MCalibrationChargePix::GetLoGainMean()  const 
+Float_t MCalibrationChargePix::GetConvertedLoGainMean()  const 
 {
   return fLoGainMean * fConversionHiLo;
@@ -335,12 +339,12 @@
 // --------------------------------------------------------------------------
 //
 // Get the Error of the Low Gain Mean: 
 //
 // Returns -1 if the variable fLoGainMean or fLoGainMeanVar are smaller than 0.
 //
 // Returns the square root of the quadratic sum of the relative variances of 
-// the fLoGainMean and fConversionHiLo, mulitplied with GetLoGainMean()
-//
-Float_t MCalibrationChargePix::GetLoGainMeanErr()  const
+// the fLoGainMean and fConversionHiLo, mulitplied with GetConvertedLoGainMean()
+//
+Float_t MCalibrationChargePix::GetConvertedLoGainMeanErr()  const
 {
   
@@ -354,13 +358,13 @@
                                  /( fLoGainMean * fLoGainMean );
 
-  return TMath::Sqrt(chargeRelVar+GetConversionHiLoRelVar()) * GetLoGainMean();
-}
-
-// --------------------------------------------------------------------------
-//
-// Get the Low Gain Sigma: 
+  return TMath::Sqrt(chargeRelVar+GetConversionHiLoRelVar()) * GetConvertedLoGainMean();
+}
+
+// --------------------------------------------------------------------------
+//
+// Get the Low Gain Sigma converted to High Gain amplification: 
 // Returns fLoGainSigma multiplied with fConversionHiLo
 //
-Float_t MCalibrationChargePix::GetLoGainSigma()  const 
+Float_t MCalibrationChargePix::GetConvertedLoGainSigma()  const 
 {
   return fLoGainSigma * fConversionHiLo;
@@ -369,12 +373,12 @@
 // --------------------------------------------------------------------------
 //
 // Get the Error of the Low Gain Sigma: 
 //
 // Returns -1 if the variable fLoGainSigma or fLoGainSigmaVar are smaller than 0.
 //
 // Returns the square root of the quadratic sum of the relative variances of 
-// the fLoGainSigma and fConversionHiLo, mulitplied with GetLoGainSigma()
-//
-Float_t MCalibrationChargePix::GetLoGainSigmaErr()  const
+// the fLoGainSigma and fConversionHiLo, mulitplied with GetConvertedLoGainSigma()
+//
+Float_t MCalibrationChargePix::GetConvertedLoGainSigmaErr()  const
 {
 
@@ -388,5 +392,5 @@
                                 /( fLoGainSigma * fLoGainSigma );
 
-  return TMath::Sqrt(sigmaRelVar+GetConversionHiLoRelVar()) * GetLoGainSigma();
+  return TMath::Sqrt(sigmaRelVar+GetConversionHiLoRelVar()) * GetConvertedLoGainSigma();
 }
 
@@ -325,8 +329,8 @@
 // --------------------------------------------------------------------------
 //
-// Get the Low Gain Mean: 
+// Get the Low Gain Mean converted to High Gain amplification: 
 // Returns fLoGainMean multiplied with fConversionHiLo
 //
@@ -335,12 +339,12 @@
 // --------------------------------------------------------------------------
 //
-// Get the Error of the Low Gain Mean: 
+// Get the Error of the converted Low Gain Mean: 
 //
 // Returns -1 if the variable fLoGainMean or fLoGainMeanVar are smaller than 0.
@@ -369,12 +373,12 @@
 // --------------------------------------------------------------------------
 //
-// Get the Error of the Low Gain Sigma: 
+// Get the Error of the converted Low Gain Sigma: 
 //
 // Returns -1 if the variable fLoGainSigma or fLoGainSigmaVar are smaller than 0.